package slimeknights.tconstruct;

import java.util.Locale;
import java.util.Random;
import java.util.function.Supplier;
import javax.annotation.Nullable;
import net.minecraft.core.Registry;
import net.minecraft.data.DataGenerator;
import net.minecraft.network.chat.Component;
import net.minecraft.network.chat.MutableComponent;
import net.minecraft.resources.ResourceLocation;
import net.minecraft.world.entity.EntityType;
import net.minecraft.world.item.Item;
import net.minecraft.world.item.Items;
import net.minecraft.world.level.block.Block;
import net.minecraft.world.level.block.Blocks;
import net.minecraftforge.api.distmarker.Dist;
import net.minecraftforge.common.MinecraftForge;
import net.minecraftforge.common.data.ExistingFileHelper;
import net.minecraftforge.data.event.GatherDataEvent;
import net.minecraftforge.eventbus.api.IEventBus;
import net.minecraftforge.eventbus.api.SubscribeEvent;
import net.minecraftforge.fml.DistExecutor;
import net.minecraftforge.fml.ModList;
import net.minecraftforge.fml.common.Mod;
import net.minecraftforge.fml.event.lifecycle.FMLCommonSetupEvent;
import net.minecraftforge.fml.javafmlmod.FMLJavaModLoadingContext;
import net.minecraftforge.registries.MissingMappingsEvent;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import slimeknights.mantle.registration.RegistrationHelper;
import slimeknights.tconstruct.common.TinkerEffect;
import slimeknights.tconstruct.common.TinkerModule;
import slimeknights.tconstruct.common.TinkerTags;
import slimeknights.tconstruct.common.config.Config;
import slimeknights.tconstruct.common.data.AdvancementsProvider;
import slimeknights.tconstruct.common.data.loot.GlobalLootModifiersProvider;
import slimeknights.tconstruct.common.data.loot.TConstructLootTableProvider;
import slimeknights.tconstruct.common.data.tags.BiomeTagProvider;
import slimeknights.tconstruct.common.data.tags.BlockEntityTypeTagProvider;
import slimeknights.tconstruct.common.data.tags.BlockTagProvider;
import slimeknights.tconstruct.common.data.tags.EnchantmentTagProvider;
import slimeknights.tconstruct.common.data.tags.EntityTypeTagProvider;
import slimeknights.tconstruct.common.data.tags.FluidTagProvider;
import slimeknights.tconstruct.common.data.tags.ItemTagProvider;
import slimeknights.tconstruct.common.network.TinkerNetwork;
import slimeknights.tconstruct.fluids.TinkerFluids;
import slimeknights.tconstruct.gadgets.TinkerGadgets;
import slimeknights.tconstruct.library.TinkerBookIDs;
import slimeknights.tconstruct.library.materials.MaterialRegistry;
import slimeknights.tconstruct.library.tools.capability.TinkerDataCapability;
import slimeknights.tconstruct.library.tools.definition.ToolDefinitionLoader;
import slimeknights.tconstruct.library.tools.layout.StationSlotLayoutLoader;
import slimeknights.tconstruct.library.utils.Util;
import slimeknights.tconstruct.plugin.DietPlugin;
import slimeknights.tconstruct.plugin.ImmersiveEngineeringPlugin;
import slimeknights.tconstruct.plugin.jsonthings.JsonThingsPlugin;
import slimeknights.tconstruct.shared.TinkerClient;
import slimeknights.tconstruct.shared.TinkerCommons;
import slimeknights.tconstruct.shared.TinkerMaterials;
import slimeknights.tconstruct.shared.block.SlimeType;
import slimeknights.tconstruct.smeltery.TinkerSmeltery;
import slimeknights.tconstruct.tables.TinkerTables;
import slimeknights.tconstruct.tools.TinkerModifiers;
import slimeknights.tconstruct.tools.TinkerToolParts;
import slimeknights.tconstruct.tools.TinkerTools;
import slimeknights.tconstruct.tools.stats.ToolType;
import slimeknights.tconstruct.world.TinkerStructures;
import slimeknights.tconstruct.world.TinkerWorld;
import slimeknights.tconstruct.world.block.CongealedSlimeBlock;

@Mod(TConstruct.MOD_ID)
@Mod.EventBusSubscriber(bus = Mod.EventBusSubscriber.Bus.MOD)
/* loaded from: TConstruct.class */
public class TConstruct {
    public static final String MOD_ID = "tconstruct";
    public static final Logger LOG = LogManager.getLogger(MOD_ID);
    public static final Random RANDOM = new Random();
    public static TConstruct instance;

    public TConstruct() {
        instance = this;
        Config.init();
        MinecraftForge.EVENT_BUS.addListener(TConstruct::missingMappings);
        IEventBus bus = FMLJavaModLoadingContext.get().getModEventBus();
        bus.register(new TinkerCommons());
        bus.register(new TinkerMaterials());
        bus.register(new TinkerFluids());
        bus.register(new TinkerGadgets());
        bus.register(new TinkerWorld());
        bus.register(new TinkerStructures());
        bus.register(new TinkerTables());
        bus.register(new TinkerModifiers());
        bus.register(new TinkerToolParts());
        bus.register(new TinkerTools());
        bus.register(new TinkerSmeltery());
        TinkerModule.initRegisters();
        TinkerNetwork.setup();
        TinkerTags.init();
        TinkerBookIDs.registerCommandSuggestion();
        DistExecutor.unsafeRunWhenOn(Dist.CLIENT, () -> {
            return TinkerClient::onConstruct;
        });
        ModList modList = ModList.get();
        if (modList.isLoaded("immersiveengineering")) {
            bus.register(new ImmersiveEngineeringPlugin());
        }
        if (modList.isLoaded("jsonthings")) {
            JsonThingsPlugin.onConstruct();
        }
        if (modList.isLoaded("diet")) {
            DietPlugin.onConstruct();
        }
    }

    @SubscribeEvent
    static void commonSetup(FMLCommonSetupEvent event) {
        MaterialRegistry.init();
        ToolDefinitionLoader.init();
        StationSlotLayoutLoader.init();
    }

    @SubscribeEvent
    static void gatherData(GatherDataEvent event) {
        DataGenerator datagenerator = event.getGenerator();
        ExistingFileHelper existingFileHelper = event.getExistingFileHelper();
        boolean server = event.includeServer();
        BlockTagProvider blockTags = new BlockTagProvider(datagenerator, existingFileHelper);
        datagenerator.m_236039_(server, blockTags);
        datagenerator.m_236039_(server, new ItemTagProvider(datagenerator, blockTags, existingFileHelper));
        datagenerator.m_236039_(server, new FluidTagProvider(datagenerator, existingFileHelper));
        datagenerator.m_236039_(server, new EntityTypeTagProvider(datagenerator, existingFileHelper));
        datagenerator.m_236039_(server, new BlockEntityTypeTagProvider(datagenerator, existingFileHelper));
        datagenerator.m_236039_(server, new BiomeTagProvider(datagenerator, existingFileHelper));
        datagenerator.m_236039_(server, new EnchantmentTagProvider(datagenerator, existingFileHelper));
        datagenerator.m_236039_(server, new TConstructLootTableProvider(datagenerator));
        datagenerator.m_236039_(server, new AdvancementsProvider(datagenerator));
        datagenerator.m_236039_(server, new GlobalLootModifiersProvider(datagenerator));
    }

    @Nullable
    private static Block missingBlock(String name) {
        boolean z = -1;
        switch (name.hashCode()) {
            case -1751944722:
                if (name.equals("blood_congealed_slime")) {
                    z = true;
                    break;
                }
                break;
            case -1448867275:
                if (name.equals("mud_bricks")) {
                    z = 6;
                    break;
                }
                break;
            case -1390024307:
                if (name.equals("lavawood")) {
                    z = 3;
                    break;
                }
                break;
            case -1351048300:
                if (name.equals("mud_bricks_stairs")) {
                    z = 8;
                    break;
                }
                break;
            case -1263370427:
                if (name.equals("blood_fluid")) {
                    z = 2;
                    break;
                }
                break;
            case -1251376061:
                if (name.equals("blood_slime")) {
                    z = false;
                    break;
                }
                break;
            case -1001041604:
                if (name.equals("lavawood_stairs")) {
                    z = 5;
                    break;
                }
                break;
            case 758362116:
                if (name.equals("mud_bricks_slab")) {
                    z = 7;
                    break;
                }
                break;
            case 1362077612:
                if (name.equals("lavawood_slab")) {
                    z = 4;
                    break;
                }
                break;
        }
        switch (z) {
            case false:
                return Blocks.f_50374_;
            case true:
                return (CongealedSlimeBlock) TinkerWorld.congealedSlime.get(SlimeType.EARTH);
            case true:
                return TinkerFluids.earthSlime.getBlock();
            case true:
                return TinkerMaterials.blazewood.get();
            case true:
                return TinkerMaterials.blazewood.getSlab();
            case true:
                return TinkerMaterials.blazewood.getStairs();
            case true:
                return Blocks.f_220844_;
            case true:
                return Blocks.f_220849_;
            case true:
                return Blocks.f_220845_;
            default:
                return null;
        }
    }

    private static void missingMappings(MissingMappingsEvent event) {
        RegistrationHelper.handleMissingMappings(event, MOD_ID, Registry.f_122901_, name -> {
            if (name.equals("blood_fluid")) {
                return TinkerFluids.earthSlime.getBlock();
            }
            return missingBlock(name);
        });
        RegistrationHelper.handleMissingMappings(event, MOD_ID, Registry.f_122904_, name2 -> {
            boolean z = -1;
            switch (name2.hashCode()) {
                case -1957697605:
                    if (name2.equals("ender_slime_sling")) {
                        z = 3;
                        break;
                    }
                    break;
                case -1906391732:
                    if (name2.equals("bronze_reinforcement")) {
                        z = 10;
                        break;
                    }
                    break;
                case -720134956:
                    if (name2.equals("ichor_bottle")) {
                        z = 9;
                        break;
                    }
                    break;
                case -621542485:
                    if (name2.equals("blood_bottle")) {
                        z = 8;
                        break;
                    }
                    break;
                case -616516657:
                    if (name2.equals("blood_bucket")) {
                        z = 7;
                        break;
                    }
                    break;
                case -532603756:
                    if (name2.equals("sky_slime_sling")) {
                        z = true;
                        break;
                    }
                    break;
                case -339213763:
                    if (name2.equals("earth_slime_sling")) {
                        z = false;
                        break;
                    }
                    break;
                case -275747179:
                    if (name2.equals("earth_slime_spawn_egg")) {
                        z = 4;
                        break;
                    }
                    break;
                case -72979333:
                    if (name2.equals("blood_slime_ball")) {
                        z = 6;
                        break;
                    }
                    break;
                case 1209955262:
                    if (name2.equals("bloodbone")) {
                        z = 5;
                        break;
                    }
                    break;
                case 1456103524:
                    if (name2.equals("ichor_slime_sling")) {
                        z = 2;
                        break;
                    }
                    break;
            }
            switch (z) {
                case false:
                    return TinkerTools.earthStaff.get();
                case true:
                    return TinkerTools.skyStaff.get();
                case true:
                    return TinkerTools.ichorStaff.get();
                case true:
                    return TinkerTools.enderStaff.get();
                case true:
                    return Items.f_42644_;
                case true:
                    return TinkerMaterials.venombone.get();
                case true:
                    return Items.f_42518_;
                case true:
                    return TinkerFluids.earthSlime.m_5456_();
                case true:
                    return (Item) TinkerFluids.slimeBottle.get(SlimeType.EARTH);
                case true:
                    return (Item) TinkerFluids.slimeBottle.get(SlimeType.ICHOR);
                case true:
                    return TinkerModifiers.obsidianReinforcement.get();
                default:
                    Block block = missingBlock(name2);
                    if (block == null) {
                        return null;
                    }
                    return block.m_5456_();
            }
        });
        RegistrationHelper.handleMissingMappings(event, MOD_ID, Registry.f_122899_, name3 -> {
            boolean z = -1;
            switch (name3.hashCode()) {
                case -946060817:
                    if (name3.equals("flowing_blood")) {
                        z = true;
                        break;
                    }
                    break;
                case 93832698:
                    if (name3.equals("blood")) {
                        z = false;
                        break;
                    }
                    break;
            }
            switch (z) {
                case false:
                    return TinkerFluids.earthSlime.getStill();
                case true:
                    return TinkerFluids.earthSlime.getFlowing();
                default:
                    return null;
            }
        });
        RegistrationHelper.handleMissingMappings(event, MOD_ID, Registry.f_122903_, name4 -> {
            if (name4.equals("earth_slime")) {
                return EntityType.f_20526_;
            }
            return null;
        });
        RegistrationHelper.handleMissingMappings(event, MOD_ID, Registry.f_122900_, name5 -> {
            boolean z = -1;
            switch (name5.hashCode()) {
                case -361295720:
                    if (name5.equals("momentum")) {
                        z = false;
                        break;
                    }
                    break;
                case 1758598466:
                    if (name5.equals("insatiable")) {
                        z = true;
                        break;
                    }
                    break;
            }
            switch (z) {
                case false:
                    return (TinkerEffect) TinkerModifiers.momentumEffect.get(ToolType.HARVEST);
                case true:
                    return (TinkerEffect) TinkerModifiers.insatiableEffect.get(ToolType.MELEE);
                default:
                    return null;
            }
        });
    }

    public static ResourceLocation getResource(String name) {
        return new ResourceLocation(MOD_ID, name);
    }

    public static <T> TinkerDataCapability.TinkerDataKey<T> createKey(String name) {
        return TinkerDataCapability.TinkerDataKey.of(getResource(name));
    }

    public static <T> TinkerDataCapability.ComputableDataKey<T> createKey(String name, Supplier<T> constructor) {
        return TinkerDataCapability.ComputableDataKey.of(getResource(name), constructor);
    }

    public static String resourceString(String res) {
        return String.format("%s:%s", MOD_ID, res);
    }

    public static String prefix(String name) {
        return "tconstruct." + name.toLowerCase(Locale.US);
    }

    public static String makeDescriptionId(String type, String name) {
        return type + ".tconstruct." + name;
    }

    public static String makeTranslationKey(String base, String name) {
        return Util.makeTranslationKey(base, getResource(name));
    }

    public static MutableComponent makeTranslation(String base, String name) {
        return Component.m_237115_(makeTranslationKey(base, name));
    }

    public static MutableComponent makeTranslation(String base, String name, Object... arguments) {
        return Component.m_237110_(makeTranslationKey(base, name), arguments);
    }

    public static void sealTinkersClass(Object self, String base, String solution) {
        String name = self.getClass().getName();
        if (!name.startsWith("slimeknights.tconstruct.")) {
            throw new IllegalStateException(base + " being extended from invalid package " + name + ". " + solution);
        }
    }
}
